pub trait App<'interrupt> {
// Required methods
fn commands(&self) -> &'static [Command];
fn call(
&mut self,
command: Command,
request: &[u8],
response: &mut BytesView,
) -> Result<(), Error>;
// Provided method
fn interrupt(&self) -> Option<&'interrupt InterruptFlag> { ... }
}Expand description
trait interface for a CTAPHID application. The application chooses which commands to register to, and will be called upon when the commands are received in the CTAPHID layer. Only one application can be registered to a particular command.
Required Methods
Provided Methods
Sourcefn interrupt(&self) -> Option<&'interrupt InterruptFlag>
fn interrupt(&self) -> Option<&'interrupt InterruptFlag>
Get access to the app interrupter
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".